==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/adm/model/OciCodeRepositoryConfiguration.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.adm.model;

/**
 * An OCI Code repository configuration extends a SCM Configuration with necessary data to reach and
 * use the OCI DevOps Code Repository. <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20220421")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = OciCodeRepositoryConfiguration.Builder.class)
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "scmType")
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class OciCodeRepositoryConfiguration extends ScmConfiguration {
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        @com.fasterxml.jackson.annotation.JsonProperty("branch")
        private String branch;

        public Builder branch(String branch) {
            this.branch = branch;
            this.__explicitlySet__.add("branch");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonProperty("buildFileLocation")
        private String buildFileLocation;

        public Builder buildFileLocation(String buildFileLocation) {
            this.buildFileLocation = buildFileLocation;
            this.__explicitlySet__.add("buildFileLocation");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonProperty("isAutomergeEnabled")
        private Boolean isAutomergeEnabled;

        public Builder isAutomergeEnabled(Boolean isAutomergeEnabled) {
            this.isAutomergeEnabled = isAutomergeEnabled;
            this.__explicitlySet__.add("isAutomergeEnabled");
            return this;
        }
        /**
         * The Oracle Cloud Identifier
         * ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the
         * OCI DevOps repository.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("ociCodeRepositoryId")
        private String ociCodeRepositoryId;

        /**
         * The Oracle Cloud Identifier
         * ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the
         * OCI DevOps repository.
         *
         * @param ociCodeRepositoryId the value to set
         * @return this builder
         */
        public Builder ociCodeRepositoryId(String ociCodeRepositoryId) {
            this.ociCodeRepositoryId = ociCodeRepositoryId;
            this.__explicitlySet__.add("ociCodeRepositoryId");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public OciCodeRepositoryConfiguration build() {
            OciCodeRepositoryConfiguration model =
                    new OciCodeRepositoryConfiguration(
                            this.branch,
                            this.buildFileLocation,
                            this.isAutomergeEnabled,
                            this.ociCodeRepositoryId);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(OciCodeRepositoryConfiguration model) {
            if (model.wasPropertyExplicitlySet("branch")) {
                this.branch(model.getBranch());
            }
            if (model.wasPropertyExplicitlySet("buildFileLocation")) {
                this.buildFileLocation(model.getBuildFileLocation());
            }
            if (model.wasPropertyExplicitlySet("isAutomergeEnabled")) {
                this.isAutomergeEnabled(model.getIsAutomergeEnabled());
            }
            if (model.wasPropertyExplicitlySet("ociCodeRepositoryId")) {
                this.ociCodeRepositoryId(model.getOciCodeRepositoryId());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    @Deprecated
    public OciCodeRepositoryConfiguration(
            String branch,
            String buildFileLocation,
            Boolean isAutomergeEnabled,
            String ociCodeRepositoryId) {
        super(branch, buildFileLocation, isAutomergeEnabled);
        this.ociCodeRepositoryId = ociCodeRepositoryId;
    }

    /**
     * The Oracle Cloud Identifier
     * ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the OCI
     * DevOps repository.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("ociCodeRepositoryId")
    private final String ociCodeRepositoryId;

    /**
     * The Oracle Cloud Identifier
     * ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the OCI
     * DevOps repository.
     *
     * @return the value
     */
    public String getOciCodeRepositoryId() {
        return ociCodeRepositoryId;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("OciCodeRepositoryConfiguration(");
        sb.append("super=").append(super.toString(includeByteArrayContents));
        sb.append(", ociCodeRepositoryId=").append(String.valueOf(this.ociCodeRepositoryId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof OciCodeRepositoryConfiguration)) {
            return false;
        }

        OciCodeRepositoryConfiguration other = (OciCodeRepositoryConfiguration) o;
        return java.util.Objects.equals(this.ociCodeRepositoryId, other.ociCodeRepositoryId)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.ociCodeRepositoryId == null
                                ? 43
                                : this.ociCodeRepositoryId.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.63.1-sources.jar: com/oracle/bmc/adm/model/OciCodeRepositoryConfiguration.java <==
/**
 * Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.adm.model;

/**
 * An OCI Code repository configuration extends a SCM Configuration with necessary data to reach and
 * use the OCI DevOps Code Repository. <br>
 * Note: Objects should always be created or deserialized using the {@link Builder}. This model
 * distinguishes fields that are {@code null} because they are unset from fields that are explicitly
 * set to {@code null}. This is done in the setter methods of the {@link Builder}, which maintain a
 * set of all explicitly set fields called {@link Builder#__explicitlySet__}. The {@link
 * #hashCode()} and {@link #equals(Object)} methods are implemented to take the explicitly set
 * fields into account. The constructor, on the other hand, does not take the explicitly set fields
 * into account (since the constructor cannot distinguish explicit {@code null} from unset {@code
 * null}).
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20220421")
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(
        builder = OciCodeRepositoryConfiguration.Builder.class)
@com.fasterxml.jackson.annotation.JsonTypeInfo(
        use = com.fasterxml.jackson.annotation.JsonTypeInfo.Id.NAME,
        include = com.fasterxml.jackson.annotation.JsonTypeInfo.As.PROPERTY,
        property = "scmType")
@com.fasterxml.jackson.annotation.JsonFilter(
        com.oracle.bmc.http.client.internal.ExplicitlySetBmcModel.EXPLICITLY_SET_FILTER_NAME)
public final class OciCodeRepositoryConfiguration extends ScmConfiguration {
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(withPrefix = "")
    public static class Builder {
        @com.fasterxml.jackson.annotation.JsonProperty("branch")
        private String branch;

        public Builder branch(String branch) {
            this.branch = branch;
            this.__explicitlySet__.add("branch");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonProperty("buildFileLocation")
        private String buildFileLocation;

        public Builder buildFileLocation(String buildFileLocation) {
            this.buildFileLocation = buildFileLocation;
            this.__explicitlySet__.add("buildFileLocation");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonProperty("isAutomergeEnabled")
        private Boolean isAutomergeEnabled;

        public Builder isAutomergeEnabled(Boolean isAutomergeEnabled) {
            this.isAutomergeEnabled = isAutomergeEnabled;
            this.__explicitlySet__.add("isAutomergeEnabled");
            return this;
        }
        /**
         * The Oracle Cloud Identifier
         * ([OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the
         * OCI DevOps repository.
         */
        @com.fasterxml.jackson.annotation.JsonProperty("ociCodeRepositoryId")
        private String ociCodeRepositoryId;

        /**
         * The Oracle Cloud Identifier
         * ([OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the
         * OCI DevOps repository.
         *
         * @param ociCodeRepositoryId the value to set
         * @return this builder
         */
        public Builder ociCodeRepositoryId(String ociCodeRepositoryId) {
            this.ociCodeRepositoryId = ociCodeRepositoryId;
            this.__explicitlySet__.add("ociCodeRepositoryId");
            return this;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        private final java.util.Set<String> __explicitlySet__ = new java.util.HashSet<String>();

        public OciCodeRepositoryConfiguration build() {
            OciCodeRepositoryConfiguration model =
                    new OciCodeRepositoryConfiguration(
                            this.branch,
                            this.buildFileLocation,
                            this.isAutomergeEnabled,
                            this.ociCodeRepositoryId);
            for (String explicitlySetProperty : this.__explicitlySet__) {
                model.markPropertyAsExplicitlySet(explicitlySetProperty);
            }
            return model;
        }

        @com.fasterxml.jackson.annotation.JsonIgnore
        public Builder copy(OciCodeRepositoryConfiguration model) {
            if (model.wasPropertyExplicitlySet("branch")) {
                this.branch(model.getBranch());
            }
            if (model.wasPropertyExplicitlySet("buildFileLocation")) {
                this.buildFileLocation(model.getBuildFileLocation());
            }
            if (model.wasPropertyExplicitlySet("isAutomergeEnabled")) {
                this.isAutomergeEnabled(model.getIsAutomergeEnabled());
            }
            if (model.wasPropertyExplicitlySet("ociCodeRepositoryId")) {
                this.ociCodeRepositoryId(model.getOciCodeRepositoryId());
            }
            return this;
        }
    }

    /** Create a new builder. */
    public static Builder builder() {
        return new Builder();
    }

    public Builder toBuilder() {
        return new Builder().copy(this);
    }

    @Deprecated
    public OciCodeRepositoryConfiguration(
            String branch,
            String buildFileLocation,
            Boolean isAutomergeEnabled,
            String ociCodeRepositoryId) {
        super(branch, buildFileLocation, isAutomergeEnabled);
        this.ociCodeRepositoryId = ociCodeRepositoryId;
    }

    /**
     * The Oracle Cloud Identifier
     * ([OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the OCI
     * DevOps repository.
     */
    @com.fasterxml.jackson.annotation.JsonProperty("ociCodeRepositoryId")
    private final String ociCodeRepositoryId;

    /**
     * The Oracle Cloud Identifier
     * ([OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm)) of the OCI
     * DevOps repository.
     *
     * @return the value
     */
    public String getOciCodeRepositoryId() {
        return ociCodeRepositoryId;
    }

    @Override
    public String toString() {
        return this.toString(true);
    }

    /**
     * Return a string representation of the object.
     *
     * @param includeByteArrayContents true to include the full contents of byte arrays
     * @return string representation
     */
    public String toString(boolean includeByteArrayContents) {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("OciCodeRepositoryConfiguration(");
        sb.append("super=").append(super.toString(includeByteArrayContents));
        sb.append(", ociCodeRepositoryId=").append(String.valueOf(this.ociCodeRepositoryId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof OciCodeRepositoryConfiguration)) {
            return false;
        }

        OciCodeRepositoryConfiguration other = (OciCodeRepositoryConfiguration) o;
        return java.util.Objects.equals(this.ociCodeRepositoryId, other.ociCodeRepositoryId)
                && super.equals(other);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.ociCodeRepositoryId == null
                                ? 43
                                : this.ociCodeRepositoryId.hashCode());
        return result;
    }
}
